@@ -4,13 +4,14 @@
 
 #include <initializer_list>  // for initializer_list
 
-#include "cpp11/R.hpp"   // for SEXP, SEXPREC, literals
-#include "cpp11/as.hpp"  // for as_sexp
+#include "cpp11/R.hpp"     // for SEXP, SEXPREC, literals
+#include "cpp11/as.hpp"    // for as_sexp
+#include "cpp11/sexp.hpp"  // for sexp
 
 namespace cpp11 {
 class named_arg {
  public:
-  constexpr explicit named_arg(const char* name) : name_(name), value_(nullptr) {}
+  explicit named_arg(const char* name) : name_(name), value_(R_NilValue) {}
   named_arg& operator=(std::initializer_list<int> il) {
     value_ = as_sexp(il);
     return *this;
@@ -33,14 +34,12 @@ class named_arg {
 
  private:
   const char* name_;
-  SEXP value_;
+  sexp value_;
 };
 
 namespace literals {
 
-constexpr named_arg operator"" _nm(const char* name, std::size_t) {
-  return named_arg(name);
-}
+inline named_arg operator"" _nm(const char* name, std::size_t) { return named_arg(name); }
 
 }  // namespace literals
 
